@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 ###############################################################################
 # $Id$
@@ -75,6 +75,8 @@ def DoesDriverHandleExtension(drv, ext):
 
 
 def GetExtension(filename):
+    if filename.lower().endswith('.shp.zip'):
+        return 'shp.zip'
     ext = os.path.splitext(filename)[1]
     if ext.startswith('.'):
         ext = ext[1:]
@@ -110,7 +112,7 @@ def GetOutputDriverFor(filename):
         else:
             raise Exception("Cannot guess driver for %s" % filename)
     elif len(drv_list) > 1:
-        print("Several drivers matching %s extension. Using %s" % (ext, drv_list[0]))
+        print("Several drivers matching %s extension. Using %s" % (ext if ext else '', drv_list[0]))
     return drv_list[0]
 
 #############################################################################
